import { OnInit, OnChanges, SimpleChange, EventEmitter } from '@angular/core';
import { PeticionCita } from '../../common/data/peticion-cita';
import { ResumenCita } from '../../common/data/resumen-cita';
/** Clase abstracta que define el comportamiento base de un paso de una reserva de cita. */
export declare abstract class ReservarCitaPaso implements OnInit, OnChanges {
    pasoNombre: string;
    peticion: PeticionCita;
    resumen: ResumenCita;
    visible: boolean;
    pasoAnterior: EventEmitter<Object>;
    pasoSiguiente: EventEmitter<Object>;
    esCatalanSeleccionado: boolean;
    /** Constructor. */
    constructor(pasoNombre: string);
    /** Inicialización del componente. */
    ngOnInit(): void;
    /** Se activa con el cambio del input "visible", por lo que solo ejecutamos refreshDatosVisible() cuando el usuario vuelve al paso. */
    ngOnChanges(changes: {
        [propKey: string]: SimpleChange;
    }): void;
    /** Carga de datos iniciales (desde ngOnInit()). */
    loadDatosInicio(): void;
    /** Refresco de datos al volver al paso (desde otro paso). */
    refreshDatosVisible(): void;
    /** Validación del paso para poder continuar al siguiente. */
    validarPaso(): boolean;
    /** Actualización de la información general de la reserva de cita (petición, resumen). */
    updateReservaCita(): void;
    /** Navegación al paso anterior. */
    goToPasoAnterior(): void;
    /** Navegación al paso siguiente. */
    goToPasoSiguiente(): void;
    /** Receptor del reset general. */
    reset(): void;
    /** Acciones correspondientes al paso cuando ocurre un reset general. */
    resetActions(): void;
}
