"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var moment = require("moment");
var CustomValidators = (function () {
    function CustomValidators() {
    }
    // Método para unir validadores
    // Método para unir validadores
    CustomValidators.compose = 
    // Método para unir validadores
    function (validators) {
        return function (g) {
            // ejecutamos cada uno de los validadores y unimos sus resultados
            return validators
                .map(function (validator) { return validator(g); })
                .reduce(function (acc, result) {
                if (result === void 0) { result = {}; }
                return Object.assign(acc, result);
            }, {});
        };
    };
    CustomValidators.required = function (control) {
        if (!control.value) {
            return { "required": true };
        }
        else {
            return null;
        }
    };
    /** Fecha con formato dd/mm/yyyy. */
    /** Fecha con formato dd/mm/yyyy. */
    CustomValidators.fecha = /** Fecha con formato dd/mm/yyyy. */
    function (control) {
        var error = { "fecha": true };
        if (!control.value) {
            return null;
        }
        var formatoValido = control.value.match("^[0-9]{2}/[0-9]{2}/[0-9]{4}$");
        if (!formatoValido) {
            return error;
        }
        var m = moment(control.value, "DD/MM/YYYY");
        return (m.isValid()) ? null : error;
    };
    /** RFC 2822 compliant regex. */
    /** RFC 2822 compliant regex. */
    CustomValidators.email = /** RFC 2822 compliant regex. */
    function (control) {
        if (!control.value || control.value.match(/^\S+@([-\w]+\.)+\w+$/g)) {
            return null;
        }
        else {
            return { "email": true };
        }
    };
    CustomValidators.codigoAlfanumerico = function (control) {
        if (!control.value || control.value.match(/^[0-9a-zA-Z]{1,25}$/g)) {
            return null;
        }
        else {
            return { "codigoAlfanumerico": true };
        }
    };
    CustomValidators.cp = function (control) {
        if (!control.value || control.value.match(/^[0-9]{5}$/g)) {
            return null;
        }
        else {
            return { "cp": true };
        }
    };
    CustomValidators.telefono = function (control) {
        if (!control.value || control.value.match(/^(\+34)?[0-9]{9}$/g)) {
            return null;
        }
        else {
            return { "telefono": true };
        }
    };
    CustomValidators.nombre = function (control) {
        if (!control.value || control.value.match(/^([A-Za-z0-9_\.\,\'\"\(\)\;\:\-\/\@\?\%\?\¿\&\+\-\*\/\ \n\rºª'´’·ïü?`áéíóúÁÉÍÓÚàèìòùÀÈÌÒÙÄËÏÖÜäëïöüñÑçÇ¡!])+$/g)) {
            return null;
        }
        else {
            return { "nombre": true };
        }
    };
    CustomValidators.numero = function (control) {
        if (control.value === "") {
            return null;
        }
        var num = Number(control.value);
        if (!isNaN(num) && (num % 1 == 0)) {
            return null;
        }
        return { "cantidad": true };
    };
    /* Según visto en: https://github.com/jquery-validation/jquery-validation/blob/master/src/additional/nifES.js */
    /* Según visto en: https://github.com/jquery-validation/jquery-validation/blob/master/src/additional/nifES.js */
    CustomValidators.nif = /* Según visto en: https://github.com/jquery-validation/jquery-validation/blob/master/src/additional/nifES.js */
    function (control) {
        var error = { "nif": true };
        if (!control.value) {
            return null;
        }
        var value = control.value.toUpperCase();
        // Basic format test
        if (!value.match("((^[A-Z]{1}[0-9]{7}[A-Z0-9]{1}$|^[T]{1}[A-Z0-9]{8}$)|^[0-9]{8}[A-Z]{1}$)")) {
            return error;
        }
        // Test NIF
        if (/^[0-9]{8}[A-Z]{1}$/.test(value)) {
            var success = ("TRWAGMYFPDXBNJZSQVHLCKE".charAt(value.substring(8, 0) % 23) === value.charAt(8));
            return (success) ? null : error;
        }
        // Test specials NIF (starts with K, L or M)
        if (/^[KLM]{1}/.test(value)) {
            var success = (value[8] === "TRWAGMYFPDXBNJZSQVHLCKE".charAt(value.substring(8, 1) % 23));
            return (success) ? null : error;
        }
        return error;
    };
    /* Según visto en: https://github.com/jquery-validation/jquery-validation/blob/master/src/additional/nieES.js */
    /* Según visto en: https://github.com/jquery-validation/jquery-validation/blob/master/src/additional/nieES.js */
    CustomValidators.nie = /* Según visto en: https://github.com/jquery-validation/jquery-validation/blob/master/src/additional/nieES.js */
    function (control) {
        var error = { "nie": true };
        if (!control.value) {
            return null;
        }
        var value = control.value.toUpperCase();
        var nieRegEx = new RegExp(/^[MXYZ]{1}[0-9]{7,8}[TRWAGMYFPDXBNJZSQVHLCKET]{1}$/gi);
        var validChars = "TRWAGMYFPDXBNJZSQVHLCKET", letter = value.substr(value.length - 1).toUpperCase(), number;
        // Quick format test
        if (value.length > 10 || value.length < 9 || !nieRegEx.test(value)) {
            return error;
        }
        // X means same number, Y means number + 10000000, Z means number + 20000000
        value = value.replace(/^[X]/, "0")
            .replace(/^[Y]/, "1")
            .replace(/^[Z]/, "2");
        number = value.length === 9 ? value.substr(0, 8) : value.substr(0, 9);
        if (validChars.charAt(parseInt(number, 10) % 23) === letter) {
            return null;
        }
        return error;
    };
    CustomValidators.nifnie = function (control) {
        var error = { "nifnie": true };
        var resultado1 = CustomValidators.nif(control);
        var resultado2 = CustomValidators.nie(control);
        return (resultado1 && resultado2) ? error : null;
    };
    CustomValidators.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    CustomValidators.ctorParameters = function () { return []; };
    return CustomValidators;
}());
exports.CustomValidators = CustomValidators;
//# sourceMappingURL=custom-validators.service.js.map